@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Deploy.py 1003 2021-03-31 18:30:57Z Lavender $
+# $Id: CloudServices.py 1197 2021-08-16 06:40:19Z Casey $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2021-04-01 02:30:57 +0800 (週四, 01 四月 2021) $
-# $Revision: 1003 $
+# $Author: Casey $
+# $Date: 2021-08-16 14:40:19 +0800 (Mon, 16 Aug 2021) $
+# $Revision: 1197 $
 
 import json
 import socket
@@ -49,7 +49,7 @@ class BaseServices(object):
     
     name = "Base"
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomain=None):
         return {
             
         }
@@ -59,7 +59,7 @@ class CloudflareService(BaseServices):
 
     name = "Cloudflare DNS"
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomain=None):
         # cf
         cf = Cloudflare(CLOUDFLARE_EMAIL, CLOUDFLARE_API_KEY)
         subdomain = tldextract.extract(domain).subdomain
@@ -82,23 +82,44 @@ class CloudflareService(BaseServices):
             ip = socket.gethostbyname(server)
         except Exception as e:
             raise RuntimeError("Can't get ip of server: %s" % server)
+
+        domains = []
+        domains.append(domain)
+        if aliasDomain:
+            # aliasDomain 可能會有多個，且用逗號區隔
+            aliasDomain = aliasDomain.split(",")
+            for alias in aliasDomain:
+                domains.append(alias)
         
         # check dns 
         if ip and zoneID:
-            result = cf.dns_records(zoneID, domain).get('result')
-            if not result:
-                # creat dns
-                result = cf.create_record(zoneID, domain, ip)
-                if not result.get('success'):
-                    raise RuntimeError("Create Cloudflare DNS error: %s" % result)
+            finalResult = []
+            for domain in domains:
                 result = cf.dns_records(zoneID, domain).get('result')
-            result = result[0]
-           
+                if not result:
+                    # creat dns
+                    result = cf.create_record(zoneID, domain, ip)
+                    if not result.get('success'):
+                        raise RuntimeError("Create Cloudflare DNS error: %s" % result)
+                    result = cf.dns_records(zoneID, domain).get('result')
+                    result = result[0]
+                else:
+                    result = result[0]
+                    # update
+                    result = cf.update_record(zoneID, result["id"], domain, result['ttl'], ip, result['proxied'])
+                    result = result["result"]
+
+                finalResult.append(result)
+
+            name = ''
+            for result in finalResult:
+                name += f'{result.get("name")}, '
+
             return {
-                'zone name': result.get("zone_name"), 
-                'name': result.get("name"), 
-                'type': result.get("type"), 
-                'content': result.get("content")
+                'zone name': finalResult[0].get("zone_name"), 
+                'name': name, 
+                'type': finalResult[0].get("type"), 
+                'content': finalResult[0].get("content")
             }
             
         raise RuntimeError("Can't get ip of server and zoneID: %s" % server)
@@ -359,7 +380,7 @@ class HealthchecksService(BaseServices):
         return hchkAPIKey, integrations
         
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomain=None):
         # connect 
         browser = self.loginHealthchecks()
        
@@ -453,7 +474,7 @@ class SentryService(BaseServices):
         browser["email"] = managerEmail
         browser.submit_selected()
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomain=None):
         # connect 
         browser = self.loginSentry()
         
